exitCodes property

  1. @override
Map<int, String> get exitCodes
override

Exit codes of the command with their meaning, except the common ones (0 - success, 2 - error).

Used in a machine readable index of the commands (see alex agents guide).

Implementation

@override
Map<int, String> get exitCodes => const {
      kExitCodeAnalyzeFailed: 'analyze failed',
      kExitCodeTestFailed: 'tests failed',
      kExitCodeBuildFailed: 'build failed',
    };