PubspecCommand class
- Inheritance
-
- Object
- Command<
int> - AlexCommand
- PubspecCommand
Constructors
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- category → String
-
The command's category.
no setterinherited
- cmd → Cmd
-
no setterinherited
- config → AlexConfig
-
no setterinherited
- console ↔ Console
-
getter/setter pairinherited
- description → String
-
A description of this command, included in usage.
no setterinherited
-
exitCodes
→ Map<
int, String> -
Exit codes of the command with their meaning,
except the common ones (
0- success,2- error).no setterinherited - flutter → FlutterCmd
-
no setterinherited
- fullName → String
-
Full name of the command with all the parent commands,
for example
code check.no setterinherited - globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - isInteractive → bool
-
Whether the command can ask a question in the standard input.
no setterinherited
- isJsonFormat → bool
-
Whether a machine readable result is requested (
--format=json).no setterinherited - isNonInteractive → bool
-
Whether the command is forbidden to ask questions
in the standard input (
--non-interactive).no setterinherited - isVerbose → bool
-
no setterinherited
- isVerboseFlutterCmd → bool
-
no setterinherited
- name → String
-
The name of this command.
no setterinherited
- out → Logger
-
no setterinherited
-
parent
→ Command<
int> ? -
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<
int> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → AlexSettings
-
no setterinherited
-
subcommands
→ Map<
String, Command< int> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited
Methods
-
addSubcommand(
Command< int> command) → void -
Adds
Commandas a subcommand of this.inherited -
doRun(
) → Future< int> -
override
-
error(
int code, {String? message}) → int -
Returns error code and prints a error message if provided.
inherited
-
errorBy(
RunException exception, {String? title}) → int -
Returns error code by exception.
inherited
-
errorNoAnswer(
String question, String option) → int -
Returns an error code and prints a message about the
optionthat should be passed instead of the answer to a question.inherited -
findConfigAndSetWorkingDir(
) → AlexConfig -
inherited
-
getGit(
AlexConfig config, {bool isDemo = false}) → GitCommands -
inherited
-
jsonResult(
{required int exitCode, String? summary, Map< String, dynamic> data = const {}}) → int -
Prints the result of the command in the standard output
as a single JSON object and returns the
exitCode.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printError(
String message) → void -
Prints error message in error output.
inherited
-
printInfo(
String message) → void -
Prints some info message in output.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
printVerbose(
String message) → void -
Prints message if verbose flag is on.
inherited
-
printWarning(
String message) → void -
Prints warning message in output.
inherited
-
run(
) → Future< int> -
Runs this command.
inherited
-
setCurrentDir(
String path) → void -
inherited
-
success(
{String? message}) → int -
Prints 0 code and prints a success message if provided.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited