incrementVersion method

Future<Version> incrementVersion(
  1. Version value
)

Increments the version value for the next release and returns a new one.

A patch and a build number are incremented, no matter which part was incremented for the release itself.

Implementation

Future<Version> incrementVersion(Version value) async {
  printVerbose('Increment version');

  final version = VersionIncrement.patch.apply(value, incrementBuild: true);
  await _saveVersion(version);

  return version;
}