Properties
-
aliases
→ List<String>
-
Alternate names for this command.
no setterinherited
-
argParser
→ ArgParser
-
The argument parser for this command.
no setterinherited
-
argResults
→ ArgResults?
-
The parsed argument results for this command.
no setterinherited
-
category
→ String
-
The command's category.
no setterinherited
-
cmd
→ Cmd
-
no setterinherited
-
config
→ AlexConfig
-
no setterinherited
-
console
↔ Console
-
getter/setter pairinherited
-
description
→ String
-
A description of this command, included in usage.
no setterinherited
-
exitCodes
→ Map<int, String>
-
Exit codes of the command with their meaning,
except the common ones (
0 - success, 2 - error).
no setterinherited
-
flutter
→ FlutterCmd
-
no setterinherited
-
fullName
→ String
-
Full name of the command with all the parent commands,
for example
code check.
no setterinherited
-
globalResults
→ ArgResults?
-
The parsed global argument results.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hidden
→ bool
-
Whether or not this command should be hidden from help listings.
no setterinherited
-
invocation
→ String
-
A single-line template for how to invoke this command (e.g.
"pub get package").
no setterinherited
-
isInteractive
→ bool
-
Whether the command can ask a question in the standard input.
no setterinherited
-
isJsonFormat
→ bool
-
Whether a machine readable result is requested (
--format=json).
no setterinherited
-
isNonInteractive
→ bool
-
Whether the command is forbidden to ask questions
in the standard input (
--non-interactive).
no setterinherited
-
isVerbose
→ bool
-
no setterinherited
-
isVerboseFlutterCmd
→ bool
-
no setterinherited
-
name
→ String
-
The name of this command.
no setterinherited
-
out
→ Logger
-
no setterinherited
-
parent
→ Command<int>?
-
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<int>?
-
The command runner for this command.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
settings
→ AlexSettings
-
no setterinherited
-
subcommands
→ Map<String, Command<int>>
-
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<String>
-
Alternate non-functional names for this command.
no setterinherited
-
summary
→ String
-
A short description of this command, included in
parent's
CommandRunner.usage.
no setterinherited
-
takesArguments
→ bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
-
usage
→ String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.
no setterinherited