result function

void result(
  1. String value
)

Prints a result of a command in the standard output.

Should be used only for a machine readable result, see setMessagesOutputToStdErr.

Implementation

void result(String value) => stdout.writeln(value);