setMessagesOutputToStdErr function

void setMessagesOutputToStdErr({
  1. bool value = true,
})

Redirects all messages (info and verbose) to the error output.

Should be used when the standard output is reserved for a machine readable result of a command (see --format=json), so any other message can't be mixed with it.

Implementation

void setMessagesOutputToStdErr({bool value = true}) =>
    _useStdErrForMessages = value;