AlexCommand class abstract

Базовый класс команды.

Inheritance
Implementers

Constructors

AlexCommand(String _name, String _description, [List<String> _aliases = const []])

Properties

aliases List<String>
Alternate names for this command.
no setteroverride
argParser → ArgParser
The argument parser for this command.
no setteroverride
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category String
The command's category.
no setterinherited
cmd → Cmd
no setter
config AlexConfig
no setter
console ↔ Console
getter/setter pair
description String
A description of this command, included in usage.
no setteroverride
exitCodes Map<int, String>
Exit codes of the command with their meaning, except the common ones (0 - success, 2 - error).
no setter
flutter → FlutterCmd
no setter
fullName String
Full name of the command with all the parent commands, for example code check.
no setter
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
isInteractive bool
Whether the command can ask a question in the standard input.
no setter
isJsonFormat bool
Whether a machine readable result is requested (--format=json).
no setter
isNonInteractive bool
Whether the command is forbidden to ask questions in the standard input (--non-interactive).
no setter
isVerbose bool
no setter
isVerboseFlutterCmd bool
no setter
name String
The name of this command.
no setteroverride
out → Logger
no setter
parent → Command<int>?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner<int>?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings → AlexSettings
no setter
subcommands Map<String, Command<int>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command<int> command) → void
Adds Command as a subcommand of this.
inherited
doRun() Future<int>
error(int code, {String? message}) int
Returns error code and prints a error message if provided.
errorBy(RunException exception, {String? title}) int
Returns error code by exception.
errorNoAnswer(String question, String option) int
Returns an error code and prints a message about the option that should be passed instead of the answer to a question.
findConfigAndSetWorkingDir() AlexConfig
getGit(AlexConfig config, {bool isDemo = false}) → GitCommands
jsonResult({required int exitCode, String? summary, Map<String, dynamic> data = const {}}) int
Prints the result of the command in the standard output as a single JSON object and returns the exitCode.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printError(String message) → void
Prints error message in error output.
printInfo(String message) → void
Prints some info message in output.
printUsage() → void
Prints the usage information for this command.
inherited
printVerbose(String message) → void
Prints message if verbose flag is on.
printWarning(String message) → void
Prints warning message in output.
run() Future<int>
Runs this command.
override
setCurrentDir(String path) → void
success({String? message}) int
Prints 0 code and prints a success message if provided.
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited