AlexCommand constructor
Implementation
AlexCommand(this._name, this._description, [this._aliases = const []]) {
// A command that can ask a question should be able to run
// in a script too, so it always has a way to forbid the questions.
if (isInteractive) _argParser.addNonInteractiveFlag();
}