Exit codes of the command with their meaning, except the common ones (0 - success, 2 - error).
0
2
Used in a machine readable index of the commands (see alex agents guide).
alex agents guide
Map<int, String> get exitCodes => const {};