isInteractive property
bool
get
isInteractive
Whether the command can ask a question in the standard input.
Such a command can't be used by a script or an agent without the options that provide all the answers.
Used in a machine readable index of the commands
(see alex agents guide).
Implementation
bool get isInteractive => false;