addNonInteractiveFlag method

void addNonInteractiveFlag()

Adds the --non-interactive flag.

Added automatically for a command that can ask a question, see AlexCommand.isInteractive.

Implementation

void addNonInteractiveFlag() => addFlag(
      kNonInteractive,
      help: 'Do not ask anything in the standard input: '
          'fail with an explanation instead of waiting for an answer. '
          'For scripts and CI.',
      negatable: false,
    );