GuideCommand constructor
GuideCommand()
Implementation
GuideCommand()
: super(
'guide',
'Print a short guide of alex for an AI agent or a script.\n\n'
'The guide is generated from the commands tree of the installed '
'version, so it always matches the tool: '
'the list of commands, their options, '
'which of them support a machine readable output '
'and which are interactive, and the exit codes.\n\n'
'Pass a command path to print the guide for it only, '
'for example: alex agents guide l10n.\n\n'
'Exit code is 0 if the guide is printed, '
'$_kExitCodeUnknownCommand if there is no command '
'with the specified path.',
) {
argParser.addFormatOption();
}