errorNoAnswer method

  1. @protected
int errorNoAnswer(
  1. String question,
  2. String option
)

Returns an error code and prints a message about the option that should be passed instead of the answer to a question.

Implementation

@protected
int errorNoAnswer(String question, String option) => error(
      1,
      message: 'Can not ask "$question" in the non-interactive mode. '
          'Pass $option or run without --$kNonInteractive.',
    );