exitCodes property

Map<int, String> get exitCodes

Exit codes of the command with their meaning, except the common ones (0 - success, 2 - error).

Used in a machine readable index of the commands (see alex agents guide).

Implementation

Map<int, String> get exitCodes => const {};