isNonInteractive property
Whether the command is forbidden to ask questions
in the standard input (--non-interactive).
Instead of waiting for an answer that will never come, the command should fail with a message about the option that provides it.
Implementation
@protected
bool get isNonInteractive =>
argResults?.options.contains(kNonInteractive) == true &&
argResults![kNonInteractive] == true;